<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>Fermer (%1)</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Minimiser</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Agrandir</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>Lever l&apos;alerte</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln mot</numerusform>
            <numerusform>%Ln mots</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln minute</numerusform>
            <numerusform>%Ln minutes</numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation>0%</translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln minute(s)</source>
        <translation>
            <numerusform>%L1% sur %Ln minute</numerusform>
            <numerusform>%L1% sur %Ln minutes</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln word(s)</source>
        <translation>
            <numerusform>%L1% sur %Ln mot</numerusform>
            <numerusform>%L1% sur %Ln mots</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation>Progrès quotidien</translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation>Session la plus longue</translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation>Session actuelle</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n jour</numerusform>
            <numerusform>%n jours</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;ntiret; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%L1% of daily goal</source>
        <translation>%L1% de l&apos;objectif quotidien</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation>Choisir la langue</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Sans titre %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation>%1 (Lecture seule)</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Désolé</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>Impossible d&apos;enregistrer « %1 ».</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>Enregistrer sous</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>Impossible d&apos;écraser « %1 ».</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>Renommer le fichier</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>Impossible de renommer le fichier « %1 ».</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation>Recharger le fichier ?</translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>Recharger le fichier « %1 » à partir du disque ?</translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>Toutes les modifications non enregistrées seront perdues. </translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Rechargement</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Sans titre %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Question</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>L&apos;enregistrement en texte brut effacera toute mise en forme. Voulez-vous effacer la mise en forme ? </translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>Fichier modifié</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>Le fichier « %1 » a été modifié par un autre programme.</translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>Voulez-vous recharger le fichier ? </translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Recharger</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorer</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>Fichier supprimé</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>Le fichier %1 a été supprimé par un autre programme. </translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>Voulez-vous enregistrer ou fermer le fichier ?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Impossible d&apos;ouvrir l&apos;archive.</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>Rechercher :</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>Remplacer par :</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Ignorer la casse</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>Mots entiers seulement</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>Expressions régulières</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Précédent</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Suivant</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Rechercher</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>&amp;Remplacer</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>Remplacer &amp;tout</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Chercher</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Remplacer</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>Remplacer %n occurrence ?</numerusform>
            <numerusform>Remplacer %n occurrences ?</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Question</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Désolé</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>Phrase non trouvée.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation>Texte OpenDocument</translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation>Office Open XML</translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation>Rich Text Format</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation>Texte brut</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Tous les fichiers</translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation>Tous les fichiers pris en charge</translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation>OpenDocument Flat XML</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>Vérifier l&apos;orthographe...</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(Aucune suggestion trouvée)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>Ouvrir une image</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Images</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Choisissez la langue du programme :</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Langue du système&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Note</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Veuillez redémarrer le programme pour que le changement de langue prenne effet.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Impossible d&apos;ouvrir l&apos;archive.</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistiques</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Barre d&apos;outils</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>Vérification orthographique</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>Choisir le dictionnaire</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Désolé</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>Impossible d&apos;ouvrir l&apos;archive.</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>L&apos;archive ne contient aucun dictionnaire utilisable.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Question</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Raccourcis</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>Au moins un conflit dans les raccourcis clavier. Voulez-vous continuer ? </translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>Le dictionnaire « %1 » existe déjà. Voulez-vous le remplacer ?</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>Objectif quotidien</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>Minutes :</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Mots :</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>Édition</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>Toujours centrer verticalement</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>Curseur bloc</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>Polices lissées</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>Sons de machine à écrire</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>Guillemets typographiques :</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Doubles</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Simples</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>Scènes</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>Séparateur : </translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>Enregistrement</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>Se souvenir de la position du curseur</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>Nombre de mots</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>Nombre de pages</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>Nombre de paragraphes</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>Nombre de caractères</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Caractères :</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>Paragraphes :</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>Algorithme de comptage des mots</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation>Réinitialiser le progrès quotidien pour aujourd&apos;hui ?</translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation>Écrire l&apos;ordre des octets dans des fichiers textes bruts</translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation>Format par défaut :</translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation>Réinitialiser pour aujourd&apos;hui</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historique</translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation>Se souvenir de l&apos;historique</translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation>Afficher les sessions</translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation>Progrès minimum pour les sessions :</translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>Détecter la fin des mots</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>Diviser le nombre de caractères par six</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation>Compter chaque lettre comme un mot</translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation>Algorithme de comptage des pages</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Style</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>Icône seule</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>Texte seul</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>Texte à côté des icônes</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>Texte sous les icônes</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>Position du texte :</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Actions</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Monter</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Descendre</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>Ajouter un séparateur</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Commande</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Raccourci</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Action</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>Vérifier l&apos;orthographe pendant la frappe</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>Ignorer les mots en MAJUSCULES</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>Ignorer les mots comportant des chiffres</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Langue</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>Dictionnaire personnel</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation>Supprimer le dictionnaire courant ?</translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation>Interface utilisateur</translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation>Toujours afficher la barre de défilement</translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation>Toujours afficher la barre supérieure</translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation>Toujours afficher la barre inférieure</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation>Fichier RTF non pris en charge.</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation>Fin du fichier avortée.</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Maj+Bas</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>Déplacer les scènes vers le haut</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Maj+Haut</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>Affichage de la liste des scènes</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Maj+F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>Afficher la liste des scènes (%1)</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>Masquer la liste des scènes (%1)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtre</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>Déplacer les scènes vers le bas</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>Redimensionner la liste des scènes</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>Par défaut</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>Gérer les sessions</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>S&amp;essions</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nouveau</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Dupliquer</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renommer</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>Ouvrir la session</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Nouvelle session</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation>Dupliquer la session</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>Renommer la session</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Question</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>Effacer la session sélectionnée ?</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>Nom de la session :</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Désolé</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>Le nom demandé est déjà utilisé.</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>&amp;Nouvelle...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Maj+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>&amp;Gérer...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Maj+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>Valeurs par défaut</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Raccourci :</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>Remplacement des guillemets...</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Veuillez patienter</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>Vérifier l&apos;orthographe</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Ajouter</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>&amp;Ignorer</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>Tout i&amp;gnorer</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>&amp;Modifier</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>Tout m&amp;odifier</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>Absent du dictionnaire :</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>Changer pour :</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>Vérification de l&apos;orthographe...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Veuillez patienter</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation>Poursuivre la vérification au début du fichier ?</translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>Vérification orthographique terminée.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>Symboles</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>Symboles récemment utilisés</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>Tous les symboles</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Détails</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nom :</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Insérer</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>Blocs</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Scripts</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>Sans titre %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>Nom :</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>Aucune image</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>Mosaïque</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Centrée</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>Étendue</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Mise à l&apos;échelle</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>Agrandie et rognée</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Opacité :</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Position :</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Largeur :</translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation>Coins arrondis pour l&apos;arrière-plan du texte</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation>Rayon :</translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation>Estomper l&apos;arrière-plan du texte</translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation>Ombre portée de l&apos;arrière-plan du texte</translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation>Décalage vertical :</translation>
    </message>
    <message>
        <source>Margins</source>
        <translation>Marges</translation>
    </message>
    <message>
        <source>Window:</source>
        <translation>Fenêtre :</translation>
    </message>
    <message>
        <source>Page:</source>
        <translation>Page :</translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation>Indenter la première ligne</translation>
    </message>
    <message>
        <source>Above:</source>
        <translation>Au-dessus :</translation>
    </message>
    <message>
        <source>Below:</source>
        <translation>Au-dessous :</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Supprimer l&apos;image</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation>Éditer le thème</translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation>Arrière-plan de la fenêtre</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Type :</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Couleur :</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>Image :</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation> pixels</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Gauche</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation>Arrière-plan du texte</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Droite</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texte</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>Police :</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>Fautes :</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>Interligne</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Simple</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>1,5 lignes</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Double</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>Proportionnelle</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Hauteur :</translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>Retraits et espacements de paragraphes</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation>Largeur du retrait :</translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation>Nouveau thème</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>Thèmes</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Par défaut</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation>Bleu tendre</translation>
    </message>
    <message>
        <source>Old School</source>
        <translation>Vieille école</translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation>Rêves d&apos;espace</translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation>Secrétaire</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nouveau</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Dupliquer</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Personnalisé</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Éditer</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importer</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exporter</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Question</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>Supprimer le thème « %1 » ?</translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation>Thèmes (%1)</translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>Importer un thème</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>Exporter le thème</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation>Cieux amers</translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation>Enchantement</translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation>Jeux d&apos;espionnage</translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation>Tranquilité</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Question</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>Supprimer le chronomètre ?</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Mots :&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Pages :&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Paragraphes :&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Caractères :&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>régler la durée</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>Régler l&apos;heure</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Temps d&apos;attente:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Heure :</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>Alarme</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Type :</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Mémo :</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Modifier</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>Aucun chronomètre en cours</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>Chronomètres</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nouveau</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>Récent</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Question</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>Annuler les modifications apportées aux chronomètres ?</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>Chargement des thèmes</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>Chargement des sons</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Sans titre</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Ouvrir un fichier</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>À propos de FocusWriter</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>Un traitement de texte plein écran simple</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Publié sous licence &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Utilise les icônes du thème &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Utilisé sous licence &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>Caractères : %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>Pages : %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>Paragraphes : %L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>Mots : %L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Ouverture de %1</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Sans titre %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation>Lister tous les documents</translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>Basculer vers le document suivant</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>Basculer vers le document précédent</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>Basculer vers le premier document</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>Basculer vers le dernier document</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>Basculer vers le document %1</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>Chargement des préférences</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>Le cache d&apos;urgence n&apos;est pas accessible en écriture.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Avertissement</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>FocusWriter ne s&apos;est pas fermé correctement.</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>Récupérer les informations depuis le cache d&apos;urgence ?</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>Certains fichiers n&apos;ont pas pu être ouverts.</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>Certains fichiers ont été ouverts en mode de lecture seule.</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>« %1 » est plus récent que la copie présente en cache.</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>Ouvrir le fichier plus récent ?</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>Enregistrer les modifications ?</translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>Enregistrer les modifications du fichier « %1 » avant de fermer ?</translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Vos modifications seront perdues si vous ne les enregistrez pas.</translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>Impossible de charger les sons de machine à écrire.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nouveau</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Ouvrir...</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>Rechar&amp;ger</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Enregistrer</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Enregistrer &amp;sous...</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>&amp;Renommer...</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>Enregistrer &amp;tout</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>Gérer les sessions</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Nouvelle session</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>Im&amp;primer...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>Fer&amp;mer</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Édition</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>Annu&amp;ler</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>Re&amp;faire</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Co&amp;uper</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copier</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>C&amp;oller</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>Collage sans &amp;formatage</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Maj+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>Tout &amp;sélectionner</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>Sélectionner la &amp;scène</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Maj+A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>Fo&amp;rmat</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>&amp;Gras</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>&amp;Italique</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>&amp;Souligner</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>&amp;Barrer</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>&amp;Exposant</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>I&amp;ndice</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>&amp;Aligner à gauche</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>Aligner au &amp;centre</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>Aligner à &amp;droite</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>&amp;Justifier</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>D&amp;ésindenter</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>Inden&amp;ter</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>B&amp;loc d&apos;écriture de gauche à droite</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>Bl&amp;oc d&apos;écriture de droite à gauche</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>O&amp;utils</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>&amp;Chercher...</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Occurrence &amp;suivante</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>Occurrence &amp;précédente</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>&amp;Remplacer...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>&amp;Apostrophes typographiques</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>Mettre à jour le &amp;document</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>Mettre à jour la &amp;sélection</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>Ortho&amp;graphe...</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation>Choisir la &amp;langue ...</translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>C&amp;hronomètres...</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>S&amp;ymboles...</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation>&amp;Progrès quotidien</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Configuration</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>Afficher la barre d&apos;&amp;outils</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>&amp;Montrer les icônes dans le menu</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>Texte en é&amp;vidence</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>Pl&amp;ein écran</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>M&amp;inimiser</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>&amp;Thèmes...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Préférences...</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>Zoom désactivé</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>Zoom sur une ligne</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>Zoom sur trois lignes</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>&amp;Paragraphe</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>Zoom sur paragraphe</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Langue de l&apos;application...</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Certains fichiers non pris en charge n&apos;ont pas pu être ouverts. </translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>&amp;HF</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>Une &amp;ligne</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>&amp;Trois lignes</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>À &amp;propos</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>À propos de &amp;Qt</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation>Mise en pa&amp;ge...</translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation>&amp;Titre</translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation>Titre &amp;1</translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation>Titre &amp;2</translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation>Titre &amp;3</translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation>Titre &amp;4</translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation>Titre &amp;5</translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation>Titre &amp;6</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;Normal</translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation>Mettre à jour les apostrophes typographiques du document</translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation>Mettre à jour les apostrophes typographiques de la sélection</translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation>Ctrl+Maj+`</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Files to open in current session.</source>
        <translation>Fichiers à ouvrir dans la session courante.</translation>
    </message>
</context>
</TS>
